@@ -20,7 +20,7 @@ import json
 
 from logilab.common.date import ustrftime
 
-from cubicweb.view import EntityView
+from cubicweb_web.view import EntityView
 from cubicweb.predicates import adaptable
 from cubicweb.utils import json_dumps, make_uid
 from cubicweb import _
